"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Checkbox = void 0;
const react_1 = __importStar(require("react"));
const react_native_1 = require("react-native");
const react_native_reanimated_1 = __importStar(require("react-native-reanimated"));
const react_native_unistyles_1 = require("react-native-unistyles");
const Label_1 = require("@procyon/components/Label");
const enums_1 = require("@procyon/types/enums");
const SLIDER_RIGHT_POSITION = {
    [enums_1.SizeEnum.sm]: { left: 0, right: 8 },
    [enums_1.SizeEnum.md]: { left: 2, right: 19 },
    [enums_1.SizeEnum.lg]: { left: 2, right: 30 },
    [enums_1.SizeEnum.xl]: { left: 4, right: 40 },
};
const Checkbox = (props) => {
    const { label, description, status = enums_1.StatusEnum.none, disabled, size = enums_1.SizeEnum.md, labelPosition = 'left', style, } = props;
    const [checked, setChecked] = (0, react_1.useState)(false);
    const sliderSV = (0, react_native_reanimated_1.useSharedValue)(0);
    const { styles } = (0, react_native_unistyles_1.useStyles)(styleSheet, {
        labelPosition,
        disabled,
        status,
        size,
    });
    (0, react_1.useEffect)(() => {
        sliderSV.value = SLIDER_RIGHT_POSITION[size].left;
    }, []);
    (0, react_1.useEffect)(() => {
        var _a;
        if ((_a = props.checked) !== null && _a !== void 0 ? _a : false) {
            setChecked(true);
            handleAnimation();
        }
    }, [props.checked]);
    const handleClick = (e) => {
        var _a;
        handleAnimation();
        setChecked(!checked);
        (_a = props.onClick) === null || _a === void 0 ? void 0 : _a.call(props, !checked, e);
    };
    const handleAnimation = () => {
        sliderSV.value = (0, react_native_reanimated_1.withTiming)(checked ? SLIDER_RIGHT_POSITION[size].left : SLIDER_RIGHT_POSITION[size].right);
    };
    return (react_1.default.createElement(react_native_1.View, { style: [styles.procyon_checkbox_container, style === null || style === void 0 ? void 0 : style.container], "aria-label": "checkbox" },
        label && react_1.default.createElement(Label_1.Label, { label: label }),
        react_1.default.createElement(react_native_1.Pressable, { style: [styles.procyon_checkbox_input(), style === null || style === void 0 ? void 0 : style.input], onPress: handleClick },
            react_1.default.createElement(react_native_1.View, { style: [styles.procyon_checkbox_switch(checked), style === null || style === void 0 ? void 0 : style.switch] },
                react_1.default.createElement(react_native_reanimated_1.default.View, { style: [
                        styles.procyon_checkbox_slider(),
                        {
                            marginLeft: sliderSV,
                        },
                        style === null || style === void 0 ? void 0 : style.slider,
                    ] })),
            react_1.default.createElement(react_native_1.Text, { style: [styles.procyon_checkbox_description(), style === null || style === void 0 ? void 0 : style.description] }, description))));
};
exports.Checkbox = Checkbox;
const styleSheet = (0, react_native_unistyles_1.createStyleSheet)((theme) => {
    return {
        procyon_checkbox_container: {
            padding: theme.spacing.sm,
        },
        procyon_checkbox_input: () => {
            const variantForSize = (size) => ({
                paddingTop: theme.spacing[size] - 1,
                paddingBottom: theme.spacing[size] + 4,
            });
            return {
                display: 'flex',
                alignItems: 'center',
                gap: 12,
                width: 'fit-content',
                variants: {
                    size: {
                        [enums_1.SizeEnum.sm]: variantForSize(enums_1.SizeEnum.sm),
                        [enums_1.SizeEnum.md]: variantForSize(enums_1.SizeEnum.md),
                        [enums_1.SizeEnum.lg]: variantForSize(enums_1.SizeEnum.lg),
                        [enums_1.SizeEnum.xl]: variantForSize(enums_1.SizeEnum.xl),
                    },
                    labelPosition: {
                        left: {
                            flexDirection: 'row',
                        },
                        right: {
                            flexDirection: 'row-reverse',
                        },
                    },
                },
            };
        },
        procyon_checkbox_switch: (checked) => {
            const variantForStatus = (status) => (Object.assign({}, (checked
                ? {
                    backgroundColor: theme.components.field.radioButton.active.background,
                    borderColor: theme.components.field.radioButton.active.border,
                }
                : {
                    backgroundColor: theme.components.field[status].background,
                    borderColor: theme.components.field[status].border,
                })));
            return {
                justifyContent: 'center',
                borderRadius: 50,
                borderWidth: 2,
                variants: {
                    status: {
                        [enums_1.StatusEnum.none]: variantForStatus(enums_1.StatusEnum.none),
                        [enums_1.StatusEnum.info]: variantForStatus(enums_1.StatusEnum.info),
                        [enums_1.StatusEnum.success]: variantForStatus(enums_1.StatusEnum.success),
                        [enums_1.StatusEnum.warning]: variantForStatus(enums_1.StatusEnum.warning),
                        [enums_1.StatusEnum.error]: variantForStatus(enums_1.StatusEnum.error),
                    },
                    size: {
                        [enums_1.SizeEnum.sm]: { width: 20, height: 10 },
                        [enums_1.SizeEnum.md]: { width: 40, height: 21 },
                        [enums_1.SizeEnum.lg]: { width: 60, height: 30 },
                        [enums_1.SizeEnum.xl]: { width: 80, height: 40 },
                    },
                },
            };
        },
        procyon_checkbox_slider: () => {
            return {
                borderRadius: 50,
                backgroundColor: theme.components.field.input.background,
                variants: {
                    size: {
                        [enums_1.SizeEnum.sm]: { width: 8, height: 8 },
                        [enums_1.SizeEnum.md]: { width: 15, height: 15 },
                        [enums_1.SizeEnum.lg]: { width: 24, height: 24 },
                        [enums_1.SizeEnum.xl]: { width: 32, height: 32 },
                    },
                },
            };
        },
        procyon_checkbox_description: () => {
            const variantForSize = (size) => ({
                fontSize: theme.fontSize[size],
            });
            return {
                fontFamily: theme.fontFamily,
                variants: {
                    disabled: {
                        true: {
                            color: theme.components.field.disabled.color,
                        },
                    },
                    size: {
                        [enums_1.SizeEnum.sm]: variantForSize(enums_1.SizeEnum.sm),
                        [enums_1.SizeEnum.md]: variantForSize(enums_1.SizeEnum.md),
                        [enums_1.SizeEnum.lg]: variantForSize(enums_1.SizeEnum.lg),
                        [enums_1.SizeEnum.xl]: variantForSize(enums_1.SizeEnum.xl),
                    },
                },
            };
        },
    };
});
