"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Message = void 0;
const react_1 = __importDefault(require("react"));
const react_native_1 = require("react-native");
const react_native_unistyles_1 = require("react-native-unistyles");
const enums_1 = require("@procyon/types/enums");
const CheckCircle_1 = require("./Icons/CheckCircle");
const ExclamationCircle_1 = require("./Icons/ExclamationCircle");
const ExclamationTriangle_1 = require("./Icons/ExclamationTriangle");
const InfoCircle_1 = require("./Icons/InfoCircle");
const Message = ({ status = enums_1.StatusEnum.none, title, children, }) => {
    const { styles } = (0, react_native_unistyles_1.useStyles)(styleSheet, {
        status,
    });
    return (react_1.default.createElement(react_native_1.View, { style: [styles.procyon_message_container()], "aria-label": "message" },
        react_1.default.createElement(react_native_1.View, { style: [styles.procyon_message_left()] },
            status === enums_1.StatusEnum.info && react_1.default.createElement(InfoCircle_1.InfoCircleIcon, null),
            status === enums_1.StatusEnum.success && react_1.default.createElement(CheckCircle_1.CheckCircleIcon, null),
            status === enums_1.StatusEnum.warning && react_1.default.createElement(ExclamationTriangle_1.ExclamationTriangleIcon, null),
            status === enums_1.StatusEnum.error && react_1.default.createElement(ExclamationCircle_1.ErrorIcon, null),
            status === enums_1.StatusEnum.none && react_1.default.createElement(InfoCircle_1.InfoCircleIcon, null)),
        react_1.default.createElement(react_native_1.View, { style: [styles.procyon_message_right] },
            title && react_1.default.createElement(react_native_1.Text, { style: [styles.procyon_message_title] }, title),
            children && react_1.default.createElement(react_native_1.Text, { style: [styles.procyon_message_text] }, children))));
};
exports.Message = Message;
const styleSheet = (0, react_native_unistyles_1.createStyleSheet)((theme) => {
    return {
        procyon_message_container: () => {
            const variantForStatus = (status) => ({
                borderColor: theme.components.message[status].border,
                backgroundColor: theme.components.message[status].background,
            });
            return {
                padding: theme.spacing.sm,
                display: 'flex',
                flexDirection: 'row',
                borderWidth: 1,
                borderRadius: theme.spacing.md,
                marginBottom: 10,
                variants: {
                    status: {
                        [enums_1.StatusEnum.none]: variantForStatus(enums_1.StatusEnum.none),
                        [enums_1.StatusEnum.info]: variantForStatus(enums_1.StatusEnum.info),
                        [enums_1.StatusEnum.success]: variantForStatus(enums_1.StatusEnum.success),
                        [enums_1.StatusEnum.warning]: variantForStatus(enums_1.StatusEnum.warning),
                        [enums_1.StatusEnum.error]: variantForStatus(enums_1.StatusEnum.error),
                    },
                },
            };
        },
        procyon_message_left: () => {
            const variantForStatus = (status) => ({
                color: theme.components.message[status].color,
            });
            return {
                padding: theme.spacing.md,
                fontSize: theme.fontSize.xl,
                variants: {
                    status: {
                        [enums_1.StatusEnum.none]: variantForStatus(enums_1.StatusEnum.none),
                        [enums_1.StatusEnum.info]: variantForStatus(enums_1.StatusEnum.info),
                        [enums_1.StatusEnum.success]: variantForStatus(enums_1.StatusEnum.success),
                        [enums_1.StatusEnum.warning]: variantForStatus(enums_1.StatusEnum.warning),
                        [enums_1.StatusEnum.error]: variantForStatus(enums_1.StatusEnum.error),
                    },
                },
            };
        },
        procyon_message_right: {
            padding: theme.spacing.md,
            justifyContent: 'center',
            flex: 'auto',
        },
        procyon_message_title: {
            fontFamily: theme.fontFamily,
            fontSize: theme.fontSize.lg,
            marginBottom: 10,
        },
        procyon_message_text: {
            fontFamily: theme.fontFamily,
            fontSize: theme.fontSize.sm,
        },
    };
});
